@@ -1,9 +1,11 @@
 /*
- * Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
+ * Copyright (C) 2020 UOS Technology Co., Ltd.
  *
- * Author:     zccrs <zccrs@live.com>
+ * Author:     zccrs <zhangjide@deepin.com>
  *
- * Maintainer: zccrs <zhangjide@deepin.com>
+ * Maintainer: xushitong<xushitong@uniontech.com>
+ *             max-lv<lvwujun@uniontech.com>
+ *             zhangsheng<zhangsheng@uniontech.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -356,6 +358,13 @@ bool DBlockDevice::hasFileSystem() const
     return hasFileSystem(d->dbus->path());
 }
 
+bool DBlockDevice::hasPartitionTable() const
+{
+    Q_D(const DBlockDevice);
+
+    return hasPartitionTable(d->dbus->path());
+}
+
 bool DBlockDevice::hasPartition() const
 {
     Q_D(const DBlockDevice);
@@ -382,6 +391,11 @@ bool DBlockDevice::hasFileSystem(const QString &path)
     return UDisks2::interfaceExists(path, UDISKS2_SERVICE ".Filesystem");
 }
 
+bool DBlockDevice::hasPartitionTable(const QString &path)
+{
+    return UDisks2::interfaceExists(path, UDISKS2_SERVICE ".PartitionTable");
+}
+
 bool DBlockDevice::hasPartition(const QString &path)
 {
     return UDisks2::interfaceExists(path, UDISKS2_SERVICE ".Partition");
